############################################################
#Analysis of convergence in GDP per worker of EU27 regions #
############################################################

rm(list=ls(all=TRUE))
library(stargazer)

#Load dataset
load("datasetNUTS2_CE2010_EU27_forGRV_analysis")

#Define variable
  GDPpw <- samplePerWorkerGDP_27
  
  GDPpwRel <- samplePerWorkerGDPRel_27
  colnames(GDPpwRel) <- c(1991:2008)
  
  GDPpwGR <- samplePerWorkerGDPGR_27

  numYears <- ncol(GDPpw)

  #Firtst and last year of the sample
  PROD.InitialYear.REL <- (GDPpwRel[,1])  
  PROD.FinalYear.REL <-  (GDPpwRel[,(numYears)])

  #======================#
  # Convergence Analysis #
  #======================#
   
    LogGDPpwRel_initialYear <- log(GDPpwRel[,1])    
    
    #Average growth rate of each single regions
    #NB: use geometric mean!!      
    gm_mean = function(a){prod(a+1)^(1/length(a))-1}
    averageGrowthRateSingleRegions <- apply(GDPpwGR, 1, gm_mean)

    #***************************************************#
    # Conditional Convergence (Augmented Solow's Model) #
    #***************************************************#

	#Load Human Capital data Eurostat-Pose
	hc_EU.Pose.df <- read.csv("humanCapitalRegNUTS2.csv",header=TRUE,sep=",",na.strings="NA")
	hc_EU.Pose <- data.matrix(hc_EU.Pose.df)

	hc_EU.Pose_oursample <- hc_EU.Pose[,c(5:22)]
    mean_hc_index <- rowMeans(hc_EU.Pose_oursample)
	mean_invRate <- rowMeans(sampleInvestmentRate_27[,2:ncol(sampleInvestmentRate_27)])
    mean_empGr <- rowMeans(sampleTotalEmploymentGR_27) 
	mean_empGR_augm <- mean_empGr+0.05


	####
	# Consider the investment rate as endogenous!
	
	#Define as instruments the lagged variable of the endogenous varible (i.e. its value in 1991)
    invRate_lagged <- sampleInvestment_27[,1]
    
    #2SLS
    #1) First-stage: regress invRate on all the exogenous+instruments
    firstStage <- lm(log(mean_invRate) ~ LogGDPpwRel_initialYear +log(mean_empGR_augm)+log(mean_hc_index)+ log(invRate_lagged))
    summary(firstStage)
    
    #2) Second-stage: regress y on all the exogenous+fitted values first stage
	fitted_firstStage <- firstStage$fitted
    conditionalConvergence_linear_endgInvRate <-lm(c(averageGrowthRateSingleRegions) ~ LogGDPpwRel_initialYear + fitted_firstStage +log(mean_empGR_augm)+log(mean_hc_index))
	summary(conditionalConvergence_linear_endgInvRate)
    
    
	####
	# Consider the investment rate, employment growth and human capital as endogenous!
	
	#Define as instruments the lagged variable of the endogenous varible (i.e. its value in 1991)	    
    empGr_lagged <- sampleTotalEmploymentGR_27_with1991[,1]
    hc_index_lagged <- hc_EU.Pose[,5]
    
    #2SLS
    #1) First-stage: regress invRate on all the exogenous+instruments
    firstStage_invRate <- lm(log(mean_invRate) ~ LogGDPpwRel_initialYear + log(invRate_lagged) + log(empGr_lagged)+ + log(hc_index_lagged), na.action="na.exclude")
    summary(firstStage_invRate)

    firstStage_empGr <- lm(log(mean_empGR_augm) ~ LogGDPpwRel_initialYear + log(invRate_lagged) + log(empGr_lagged)+ + log(hc_index_lagged), na.action="na.exclude")

    summary(firstStage_empGr)

    firstStage_hc <- lm(log(mean_hc_index) ~ LogGDPpwRel_initialYear + log(invRate_lagged) + log(empGr_lagged)+ + log(hc_index_lagged), na.action="na.exclude")

    summary(firstStage_hc)

    
    #2) Second-stage: regress y on all the exogenous+fitted values first stage
	fitted_firstStage_invRate <- fitted(firstStage_invRate)
	fitted_firstStage_empGr <-  fitted(firstStage_empGr)
	fitted_firstStage_hc <- fitted( firstStage_hc)
	
	
    conditionalConvergence_linear_endg <-lm(c(averageGrowthRateSingleRegions) ~ LogGDPpwRel_initialYear + fitted_firstStage_invRate + fitted_firstStage_empGr + fitted_firstStage_hc)
	summary(conditionalConvergence_linear_endg)
    





